(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2004-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* Beginning of OCamlGen, 3.3+dev4 generated code *)

let print_purpose ppf = function
  | Udebug.User -> Format.fprintf ppf "%s" "User"
  | Udebug.Library -> Format.fprintf ppf "%s" "Library"

and print_software_name ppf = function
  | s -> Lib_print.print_quoted_string ppf s
;;

let rec print_short_key_prefix ppf = function
  | Udebug.Automatic -> Format.fprintf ppf "%s" "Automatic"
  | Udebug.Short u_p ->
    Format.fprintf ppf "@[<1>%s@ " "Short";
    Upervasives_print.print_prefix ppf u_p; Format.fprintf ppf "%,@]"

and print_key_prefixes ppf = function
  | { Udebug.long = u_p; Udebug.short = s; } ->
    Format.fprintf ppf "%,@[<1>{@,"; Format.fprintf ppf "%,@[<1>long =@ ";
    Upervasives_print.print_prefix ppf u_p; Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>short =@ "; print_short_key_prefix ppf s;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@,}@]"
;;

let rec print_print pp_a ppf = function
  | f_a_u -> Lib_print.print_fun pp_a Lib_print.print_unit ppf f_a_u

and print_fun_name_print pp_a ppf = function
  | f_u_f_a_p ->
    Lib_print.print_fun Upervasives_print.print_function_name
     (print_print pp_a) ppf f_u_f_a_p
;;

let print_printing_facilities ppf = function
  | {
      Udebug.report = u_m_p;
      Udebug.debug = u_m_f;
      Udebug.warning = u_m_f0;
      Udebug.error = u_m_f1;
      Udebug.report_action = u_g_p;
      Udebug.debug_action = u_g_f;
      Udebug.warning_action = u_g_f0;
      Udebug.error_action = u_g_f1;
    } ->
    Format.fprintf ppf "%,@[<1>{@,"; Format.fprintf ppf "%,@[<1>report =@ ";
    print_print Upervasives_print.print_message ppf u_m_p;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@[<1>debug =@ ";
    print_fun_name_print Upervasives_print.print_message ppf u_m_f;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@[<1>warning =@ ";
    print_fun_name_print Upervasives_print.print_message ppf u_m_f0;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@[<1>error =@ ";
    print_fun_name_print Upervasives_print.print_message ppf u_m_f1;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>report_action =@ ";
    print_print Upervasives_print.print_gen_message ppf u_g_p;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>debug_action =@ ";
    print_fun_name_print Upervasives_print.print_gen_message ppf u_g_f;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>warning_action =@ ";
    print_fun_name_print Upervasives_print.print_gen_message ppf u_g_f0;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>error_action =@ ";
    print_fun_name_print Upervasives_print.print_gen_message ppf u_g_f1;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@,}@]"
;;

let rec print_tag ppf = function | s -> Lib_print.print_quoted_string ppf s

and print_make_tag pp_a ppf = function
  | f_a_t -> Lib_print.print_fun pp_a print_tag ppf f_a_t
;;

let print_dynamic_printing_facilities pp_a ppf = function
  | {
      Udebug.dyn_report = f_a_u_m_p;
      Udebug.dyn_debug = f_a_u_m_f;
      Udebug.dyn_warning = f_a_u_m_f0;
      Udebug.dyn_error = f_a_u_m_f1;
      Udebug.dyn_report_action = f_a_u_g_p;
      Udebug.dyn_debug_action = f_a_u_g_f;
      Udebug.dyn_warning_action = f_a_u_g_f0;
      Udebug.dyn_error_action = f_a_u_g_f1;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    Format.fprintf ppf "%,@[<1>dyn_report =@ ";
    Lib_print.print_fun pp_a (print_print Upervasives_print.print_message)
     ppf f_a_u_m_p;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@[<1>dyn_debug =@ ";
    Lib_print.print_fun pp_a
     (print_fun_name_print Upervasives_print.print_message) ppf f_a_u_m_f;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>dyn_warning =@ ";
    Lib_print.print_fun pp_a
     (print_fun_name_print Upervasives_print.print_message) ppf f_a_u_m_f0;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@[<1>dyn_error =@ ";
    Lib_print.print_fun pp_a
     (print_fun_name_print Upervasives_print.print_message) ppf f_a_u_m_f1;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>dyn_report_action =@ ";
    Lib_print.print_fun pp_a
     (print_print Upervasives_print.print_gen_message) ppf f_a_u_g_p;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>dyn_debug_action =@ ";
    Lib_print.print_fun pp_a
     (print_fun_name_print Upervasives_print.print_gen_message) ppf f_a_u_g_f;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>dyn_warning_action =@ ";
    Lib_print.print_fun pp_a
     (print_fun_name_print Upervasives_print.print_gen_message) ppf
     f_a_u_g_f0;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>dyn_error_action =@ ";
    Lib_print.print_fun pp_a
     (print_fun_name_print Upervasives_print.print_gen_message) ppf
     f_a_u_g_f1;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@,}@]"
;;

let print_specialized_printing_facilities ppf = function
  | {
      Udebug.spf_report = u_m_p;
      Udebug.spf_debug = u_m_p0;
      Udebug.spf_warning = u_m_p1;
      Udebug.spf_error = u_m_p2;
      Udebug.spf_report_action = u_g_p;
      Udebug.spf_debug_action = u_g_p0;
      Udebug.spf_warning_action = u_g_p1;
      Udebug.spf_error_action = u_g_p2;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    Format.fprintf ppf "%,@[<1>spf_report =@ ";
    print_print Upervasives_print.print_message ppf u_m_p;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@[<1>spf_debug =@ ";
    print_print Upervasives_print.print_message ppf u_m_p0;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>spf_warning =@ ";
    print_print Upervasives_print.print_message ppf u_m_p1;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@[<1>spf_error =@ ";
    print_print Upervasives_print.print_message ppf u_m_p2;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>spf_report_action =@ ";
    print_print Upervasives_print.print_gen_message ppf u_g_p;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>spf_debug_action =@ ";
    print_print Upervasives_print.print_gen_message ppf u_g_p0;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>spf_warning_action =@ ";
    print_print Upervasives_print.print_gen_message ppf u_g_p1;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>spf_error_action =@ ";
    print_print Upervasives_print.print_gen_message ppf u_g_p2;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@,}@]"
;;

let print_specialized_dynamic_printing_facilities pp_a ppf = function
  | {
      Udebug.sdpf_report = f_a_u_m_p;
      Udebug.sdpf_debug = f_a_u_m_p0;
      Udebug.sdpf_warning = f_a_u_m_p1;
      Udebug.sdpf_error = f_a_u_m_p2;
      Udebug.sdpf_report_action = f_a_u_g_p;
      Udebug.sdpf_debug_action = f_a_u_g_p0;
      Udebug.sdpf_warning_action = f_a_u_g_p1;
      Udebug.sdpf_error_action = f_a_u_g_p2;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    Format.fprintf ppf "%,@[<1>sdpf_report =@ ";
    Lib_print.print_fun pp_a (print_print Upervasives_print.print_message)
     ppf f_a_u_m_p;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@[<1>sdpf_debug =@ ";
    Lib_print.print_fun pp_a (print_print Upervasives_print.print_message)
     ppf f_a_u_m_p0;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>sdpf_warning =@ ";
    Lib_print.print_fun pp_a (print_print Upervasives_print.print_message)
     ppf f_a_u_m_p1;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@[<1>sdpf_error =@ ";
    Lib_print.print_fun pp_a (print_print Upervasives_print.print_message)
     ppf f_a_u_m_p2;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>sdpf_report_action =@ ";
    Lib_print.print_fun pp_a
     (print_print Upervasives_print.print_gen_message) ppf f_a_u_g_p;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>sdpf_debug_action =@ ";
    Lib_print.print_fun pp_a
     (print_print Upervasives_print.print_gen_message) ppf f_a_u_g_p0;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>sdpf_warning_action =@ ";
    Lib_print.print_fun pp_a
     (print_print Upervasives_print.print_gen_message) ppf f_a_u_g_p1;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>sdpf_error_action =@ ";
    Lib_print.print_fun pp_a
     (print_print Upervasives_print.print_gen_message) ppf f_a_u_g_p2;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@,}@]"
;;

(* End of OCamlGen, 3.3+dev4 generated code *)
