(***********************************************************************)
(*                                                                     *)
(*                              Ref-image                              *)
(*                                                                     *)
(*                  Image Segmentation by Refinement                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2009-2013 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: patchwork.ml,v 1.1 2013/06/13 19:01:17 fclement Exp $ *)

let patchwork_invalid_arg fun_name msg =
  Pervasives.invalid_arg (Printf.sprintf "Patchwork.%s: %s" fun_name msg)
;;

open Patchwork_types;;

(*
let gen_digest = Utype_digest.gen_unary_digest Patchwork_digest.md5;;
let digest = gen_digest "patchwork"
and location_digest = gen_digest "location"
;;
*)

let top pw = { above = []; here = pw; };;

let rec zip loc =
  match loc.above with
  | [] -> loc.here
  | Patch pw :: stps ->
    zip { above = stps; here = Stitch { patch = loc.here; weave = pw; }; }
  | Weave pw :: stps ->
    zip { above = stps; here = Stitch { patch = pw; weave = loc.here; }; }
;;

let unzip loc pw =
  let rec loop stps loc =
    match stps, loc with
    | [], loc -> loc
    | Patch _ :: stps, { here = Stitch { patch = p; weave = w; }; _ } ->
        loop stps { above = Patch w :: loc.above; here = p; }
    | Weave _ :: stps, { here = Stitch { patch = p; weave = w; }; _ } ->
        loop stps { above = Weave p :: loc.above; here = w; }
    | _, { here = Piece _; _ } ->
        patchwork_invalid_arg "unzip" "no such location"
  in
  loop (List.rev loc.above) (top pw)
;;

let fold_left f accu pw =
  let rec loop accu loc =
    match loc.here with
    | Piece pc -> f accu loc pc
    | Stitch { patch = p; weave = w; } ->
      let l = { above = Patch w :: loc.above; here = p; } in
      let accu = loop accu l in
      let l = { above = Weave p :: loc.above; here = w; } in
      loop accu l
  in
  loop accu (top pw)
;;

let rec map f = function
  | Piece pc -> Piece (f pc)
  | Stitch { patch = p; weave = w; } ->
    Stitch { patch = map f p; weave = map f w; }
;;

let push_piece_in_patch pw pc = Stitch { patch = Piece pc; weave = pw; };;

let pop_piece_in_patch = function
  | Piece _ -> patchwork_invalid_arg "pop_piece_in_patch" "no stitch found"
  | Stitch { patch = Piece _; weave = pw; } -> pw
  | Stitch { patch = _; _; } ->
    patchwork_invalid_arg "pop_piece_in_patch" "no piece in patch"
;;

let has_head_piece_in_patch = function
  | Piece _
  | Stitch { patch = Piece _; _; } -> true
  | Stitch { patch = Stitch _; _; } -> false
;;

let head_piece_in_patch = function
  | Piece pc -> pc
  | Stitch { patch = Piece pc; _; } -> pc
  | Stitch { patch = Stitch _; _; } -> raise Not_found
;;

let replace_head_piece_in_patch pc = function
  | Piece _ -> Piece pc
  | Stitch ({ patch = Piece _; _; } as pw) ->
    Stitch { pw with patch = Piece pc }
  | Stitch { patch = Stitch _; _; } -> raise Not_found
;;

let replace_head_piece_in_patch_with_pieces pcs pw =
  match pcs with
  | [] -> pop_piece_in_patch pw
  | pc :: pcs ->
    let pw = replace_head_piece_in_patch pc pw in
    List.fold_left push_piece_in_patch pw pcs
;;
